@@ -50,6 +50,7 @@ $lang["SHOWCOMPACT"] = "Vis kun områder med forskelle";
 
 // $lang["LISTING"] = "Directory listing";
 // $lang["FILEDETAIL"] = "Details";
+// $lang["VIEWAS"] = "View as";
 $lang["DIFFPREV"] = "Sammenlign med forrige";
 $lang["BLAME"] = "ændringsfordeling";
 $lang["BLAMEFOR"] = "ændringsfordeling for revision";
@@ -116,9 +117,3 @@ $lang["COMPPATH"] = "Sammenlign sti:";
 $lang["WITHPATH"] = "med sti:";
 $lang["FILEDELETED"] = "Fil slettet";
 $lang["FILEADDED"] = "Ny fil";
-
-// The following are defined by some languages to stop unwanted line splitting
-// in the template files.
-
-$lang["NOBR"] = "";
-$lang["ENDNOBR"] = "";
