@@ -55,6 +55,7 @@ $lang["SHOWCOMPACT"] = "Vis kun områder med forskjeller";
 
 // $lang["LISTING"] = "Directory listing";
 // $lang["FILEDETAIL"] = "Details";
+// $lang["VIEWAS"] = "View as";
 $lang["DIFFPREV"] = "Sammenlign med forrige";
 $lang["BLAME"] = "Ansvarlig";
 $lang["BLAMEFOR"] = "Ansvarliginformasjon for rev.";
@@ -113,7 +114,7 @@ $lang["GO"] = "Gå";
 $lang["PATHCOMPARISON"] = "Stisammenligning";
 $lang["COMPAREPATHS"] = "Sammenlign stier";
 $lang["COMPAREREVS"] = "Sammenlign revisjoner";
-$lang["PROPCHANGES"] = "Egenskapsendringer :";
+$lang["PROPCHANGES"] = "Egenskapsendringer:";
 $lang["CONVFROM"] = "Denne sammenligningen viser hva som må til for å konvertere stien ";
 $lang["TO"] = "med";
 $lang["REVCOMP"] = "Baklengs sammenligning";
@@ -121,9 +122,3 @@ $lang["COMPPATH"] = "Sammenlign sti:";
 $lang["WITHPATH"] = "Med sti:";
 $lang["FILEDELETED"] = "Fil slettet";
 $lang["FILEADDED"] = "Ny fil";
-
-// The following are defined by some languages to stop unwanted line splitting
-// in the template files.
-
-$lang["NOBR"] = "";
-$lang["ENDNOBR"] = "";
